@@ -3,7 +3,7 @@
 __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
-import os, glob, functools, re
+import os, glob, re
 from calibre import guess_type
 from calibre.customize import (FileTypePlugin, MetadataReaderPlugin,
     MetadataWriterPlugin, PreferencesPlugin, InterfaceActionBase, StoreBase)
@@ -143,14 +143,11 @@ class ComicMetadataReader(MetadataReaderPlugin):
             elif id_.startswith(b'PK'):
                 ftype = 'cbz'
         if ftype == 'cbr':
-            from calibre.utils.unrar import extract_first_alphabetically as extract_first
-            extract_first
+            from calibre.utils.unrar import extract_cover_image
         else:
-            from calibre.libunzip import extract_member
-            extract_first = functools.partial(extract_member,
-                    sort_alphabetically=True)
+            from calibre.libunzip import extract_cover_image
         from calibre.ebooks.metadata import MetaInformation
-        ret = extract_first(stream)
+        ret = extract_cover_image(stream)
         mi = MetaInformation(None, None)
         stream.seek(0)
         if ftype in {'cbr', 'cbz'}:
@@ -295,12 +292,12 @@ class DocXMetadataReader(MetadataReaderPlugin):
 class OPFMetadataReader(MetadataReaderPlugin):
 
     name        = 'Read OPF metadata'
-    file_types  = set(['opf'])
+    file_types  = {'opf'}
     description = _('Read metadata from %s files')%'OPF'
 
     def get_metadata(self, stream, ftype):
-        from calibre.ebooks.metadata.opf2 import OPF
-        return OPF(stream, os.getcwdu()).to_book_metadata()
+        from calibre.ebooks.metadata.opf import get_metadata
+        return get_metadata(stream)[0]
 
 class PDBMetadataReader(MetadataReaderPlugin):
 
@@ -435,7 +432,15 @@ class EPUBMetadataWriter(MetadataWriterPlugin):
 
     def set_metadata(self, stream, mi, type):
         from calibre.ebooks.metadata.epub import set_metadata
-        set_metadata(stream, mi, apply_null=self.apply_null, force_identifiers=self.force_identifiers)
+        q = self.site_customization or ''
+        set_metadata(stream, mi, apply_null=self.apply_null, force_identifiers=self.force_identifiers, add_missing_cover='disable-add-missing-cover' != q)
+
+    def customization_help(self, gui=False):
+        h = 'disable-add-missing-cover'
+        if gui:
+            h = '<i>' + h + '</i>'
+        return _('Enter {0} below to have the EPUB metadata writer plugin not'
+                 ' add cover images to EPUB files that have no existing cover image.').format(h)
 
 class FB2MetadataWriter(MetadataWriterPlugin):
 
@@ -684,7 +689,7 @@ from calibre.devices.sne.driver import SNE
 from calibre.devices.misc import (
     PALMPRE, AVANT, SWEEX, PDNOVEL, GEMEI, VELOCITYMICRO, PDNOVEL_KOBO,
     LUMIREAD, ALURATEK_COLOR, TREKSTOR, EEEREADER, NEXTBOOK, ADAM, MOOVYBOOK,
-    COBY, EX124G, WAYTEQ, WOXTER, POCKETBOOK626, SONYDPTS1)
+    COBY, EX124G, WAYTEQ, WOXTER, POCKETBOOK626, SONYDPTS1, CERVANTES)
 from calibre.devices.folder_device.driver import FOLDER_DEVICE_FOR_CONFIG
 from calibre.devices.kobo.driver import KOBO, KOBOTOUCH
 from calibre.devices.boeye.driver import BOEYE_BEX, BOEYE_BDX
@@ -741,7 +746,7 @@ plugins += [
     KOBO, KOBOTOUCH,
     AZBOOKA,
     FOLDER_DEVICE_FOR_CONFIG,
-    AVANT,
+    AVANT, CERVANTES,
     MENTOR,
     SWEEX,
     PDNOVEL,
@@ -1033,7 +1038,7 @@ class Columns(PreferencesPlugin):
 class Toolbar(PreferencesPlugin):
     name = 'Toolbar'
     icon = I('wizard.png')
-    gui_name = _('Toolbar')
+    gui_name = _('Toolbars')
     category = 'Interface'
     gui_category = _('Interface')
     category_order = 1
@@ -1839,7 +1844,7 @@ if __name__ == '__main__':
         ret = 0
 
         for x in ('lxml', 'calibre.ebooks.BeautifulSoup', 'uuid',
-            'calibre.utils.terminal', 'calibre.utils.magick', 'PIL', 'Image',
+            'calibre.utils.terminal', 'calibre.utils.img', 'PIL', 'Image',
             'sqlite3', 'mechanize', 'httplib', 'xml', 'inspect', 'urllib',
             'calibre.utils.date', 'calibre.utils.config', 'platform',
             'calibre.utils.zipfile', 'calibre.utils.formatter',
