@@ -131,6 +131,10 @@ class Cache(object):
     def new_api(self):
         return self
 
+    @property
+    def library_id(self):
+        return self.backend.library_id
+
     @property
     def safe_read_lock(self):
         ''' A safe read lock is a lock that does nothing if the thread already
@@ -601,7 +605,7 @@ class Cache(object):
     def get_metadata(self, book_id,
             get_cover=False, get_user_categories=True, cover_as_data=False):
         '''
-        Return metadata for the book identified by book_id as a :class:`Metadata` object.
+        Return metadata for the book identified by book_id as a :class:`calibre.ebooks.metadata.book.base.Metadata` object.
         Note that the list of formats is not verified. If get_cover is True,
         the cover is returned, either a path to temp file as mi.cover or if
         cover_as_data is True then as mi.cover_data.
@@ -1247,9 +1251,9 @@ class Cache(object):
         if path_changed:
             self._update_path({book_id})
 
-        def protected_set_field(name, val, **kwargs):
+        def protected_set_field(name, val):
             try:
-                set_field(name, val, **kwargs)
+                set_field(name, val)
             except:
                 if ignore_errors:
                     traceback.print_exc()
@@ -1476,7 +1480,7 @@ class Cache(object):
         if title:
             if isbytestring(title):
                 title = title.decode(preferred_encoding, 'replace')
-            q = icu_lower(title)
+            q = icu_lower(title).strip()
             for title in self.fields['title'].table.book_col_map.itervalues():
                 if q == icu_lower(title):
                     return True
@@ -1496,6 +1500,13 @@ class Cache(object):
         if not add_duplicates and self._has_book(mi):
             return
         series_index = (self._get_next_series_num_for(mi.series) if mi.series_index is None else mi.series_index)
+        try:
+            series_index = float(series_index)
+        except Exception:
+            try:
+                series_index = float(self._get_next_series_num_for(mi.series))
+            except Exception:
+                series_index = 1.0
         if not mi.authors:
             mi.authors = (_('Unknown'),)
         aus = mi.author_sort if mi.author_sort else self._author_sort_from_authors(mi.authors)
@@ -2002,6 +2013,13 @@ class Cache(object):
 
     @write_api
     def close(self):
+        from calibre.customize.ui import available_library_closed_plugins
+        for plugin in available_library_closed_plugins():
+            try:
+                plugin.run(self)
+            except Exception:
+                import traceback
+                traceback.print_exc()
         self.backend.close()
 
     @write_api
